@@ -35,7 +35,7 @@ class QDBusServiceWatcher;
 class XcbEventFilter : public QAbstractNativeEventFilter
 {
     public:
-        virtual bool nativeEventFilter(const QByteArray &eventType, void* message, long int* result) override;
+        bool nativeEventFilter(const QByteArray &eventType, void* message, long int* result) override;
 };
 
 class App : public QGuiApplication {
@@ -43,7 +43,7 @@ class App : public QGuiApplication {
 public:
     typedef QPair< uint, uint > TriggerKey;
     App(int &argc, char* argv[]);
-    virtual ~App();
+    ~App() override;
     void setTriggerKeys(QList< TriggerKey > triggersList);
     void setDoGrab(bool doGrab);
     bool keyboardGrabbed() { return m_keyboardGrabbed; }
