@@ -45,6 +45,9 @@
 #include <KActivities/Stats/ResultSet>
 #include <KActivities/Stats/Terms>
 
+#include <processcore/process.h>
+#include <processcore/processes.h>
+
 namespace KAStats = KActivities::Stats;
 
 using namespace KAStats;
@@ -85,7 +88,7 @@ void Backend::setToolTipItem(QQuickItem *item)
     if (item != m_toolTipItem) {
         m_toolTipItem = item;
 
-        connect(item, SIGNAL(windowChanged(QQuickWindow*)), this, SLOT(toolTipWindowChanged(QQuickWindow*)));
+        connect(item, &QQuickItem::windowChanged, this, &Backend::toolTipWindowChanged);
 
         emit toolTipItemChanged();
     }
@@ -536,6 +539,19 @@ void Backend::cancelHighlightWindows()
     updateWindowHighlight();
 }
 
+qint64 Backend::parentPid(qint64 pid) const
+{
+    KSysGuard::Processes procs;
+    procs.updateOrAddProcess(pid);
+
+    KSysGuard::Process *proc = procs.getProcess(pid);
+    if (!proc) {
+        return -1;
+    }
+
+    return proc->parentPid();
+}
+
 void Backend::windowsHovered(const QVariant &_winIds, bool hovered)
 {
     m_windowsToHighlight.clear();
