@@ -27,8 +27,8 @@ class ActivitySwitcherExtensionPlugin : public QQmlExtensionPlugin {
     Q_PLUGIN_METADATA(IID "org.kde.plasma.activityswitcher")
 
 public:
-    ActivitySwitcherExtensionPlugin(QObject *parent = Q_NULLPTR);
-    void registerTypes(const char *uri) Q_DECL_OVERRIDE;
+    explicit ActivitySwitcherExtensionPlugin(QObject *parent = nullptr);
+    void registerTypes(const char *uri) override;
 };
 
 #endif // ACTIVITY_SWITCHER_EXTENSION_PLUGIN_H
