@@ -35,13 +35,19 @@ class MainConfigurationWidget : public KCModule {
     Q_OBJECT
 public:
     MainConfigurationWidget(QWidget *parent, QVariantList args);
-    ~MainConfigurationWidget();
+    ~MainConfigurationWidget() override;
 
 public Q_SLOTS:
     void defaults() override;
     void load() override;
     void save() override;
 
+private Q_SLOTS:
+    void onChanged();
+
+private:
+    void checkDefault();
+
 private:
     D_PTR;
 };
