@@ -28,8 +28,8 @@ class ActivitiesSettingsPlugin : public QQmlExtensionPlugin {
     Q_PLUGIN_METADATA(IID "org.kde.activities.settings")
 
 public:
-    ActivitiesSettingsPlugin(QObject *parent = Q_NULLPTR);
-    void registerTypes(const char *uri) Q_DECL_OVERRIDE;
+    ActivitiesSettingsPlugin(QObject *parent = nullptr);
+    void registerTypes(const char *uri) override;
 };
 
 #endif // KACTIVITIES_IMPORTS_PLUGIN_H
