@@ -8,7 +8,7 @@
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License verstion 2 as    *
+ *   it under the terms of the GNU General Public License version 2 as     *
  *   published by the Free Software Foundation                             *
  *                                                                         *
  ***************************************************************************/
@@ -57,7 +57,14 @@ CfgEmailClient::~CfgEmailClient() {
 
 void CfgEmailClient::defaults()
 {
-    load(nullptr);
+    kmailCB->setChecked(true);
+    txtEMailClient->clear();
+    chkRunTerminal->setChecked(false);
+}
+
+bool CfgEmailClient::isDefaults() const
+{
+	return kmailCB->isChecked();
 }
 
 void CfgEmailClient::load(KConfig *)
