@@ -42,8 +42,8 @@ namespace {
         "left_ptr",
         "left_ptr_watch",
         "wait",
-        "pointing_hand",
-        "whats_this",
+        "pointer",
+        "help",
         "ibeam",
         "size_all",
         "size_fdiag",
