@@ -31,15 +31,10 @@
 #define __GLOBALPATHS_H
 
 #include <kcmodule.h>
-#include <kio/global.h>
-#include <kio/udsentry.h>
-#include <QUrl>
 
-class QFormLayout;
-class KJob;
-class KUrlRequester;
+namespace Ui { class DesktopPathsView; }
 
-namespace KIO { class Job; }
+class DesktopPathsSettings;
 
 //-----------------------------------------------------------------------------
 // The "Path" Tab contains :
@@ -49,34 +44,12 @@ class DesktopPathConfig : public KCModule
 {
     Q_OBJECT
 public:
-    DesktopPathConfig( QWidget *parent, const QVariantList &args );
-    void load() override;
-    void save() override;
-    void defaults() override;
-
-private Q_SLOTS:
-    void slotEntries( KIO::Job * job, const KIO::UDSEntryList& list);
+    DesktopPathConfig(QWidget *parent, const QVariantList &args);
+    ~DesktopPathConfig() override;
 
 private:
-    KUrlRequester* addRow(QFormLayout *lay, const QString& label, const QString& whatsThis);
-    bool xdgSavePath(KUrlRequester* ur, const QUrl& currentUrl, const char* xdgKey, const QString& type);
-
-    // Desktop Paths
-    KUrlRequester *urDesktop;
-    KUrlRequester *urAutostart;
-    KUrlRequester *urDocument;
-    KUrlRequester *urDownload;
-    KUrlRequester *urMovie;
-    KUrlRequester *urPicture;
-    KUrlRequester *urMusic;
-
-    bool moveDir( const QUrl & src, const QUrl & dest, const QString & type );
-    bool m_ok;
-    QUrl m_copyToDest; // used when the destination directory already exists
-    QUrl m_copyFromSrc;
-
-private Q_SLOTS:
-    void slotResult( KJob * job );
+    QScopedPointer<Ui::DesktopPathsView> m_ui;
+    DesktopPathsSettings *m_pathsSettings;
 };
 
 #endif
