@@ -32,11 +32,11 @@ Q_OBJECT
 
 public:
 	KCMKeyboard(QWidget *parent, const QVariantList &);
-	virtual ~KCMKeyboard();
+	~KCMKeyboard() override;
 
-	void save() Q_DECL_OVERRIDE;
-	void load() Q_DECL_OVERRIDE;
-	void defaults() Q_DECL_OVERRIDE;
+	void save() override;
+	void load() override;
+	void defaults() override;
 
 private:
 	Rules* rules;
