@@ -21,7 +21,7 @@
 #define KEYBOARD_DAEMON_H_
 
 #include <kdedmodule.h>
-#include <QtCore/QStringList>
+#include <QStringList>
 
 #include "layout_memory.h"
 #include "keyboard_dbus.h"
@@ -71,7 +71,7 @@ Q_SIGNALS:
 
 public:
     KeyboardDaemon(QObject *parent, const QList<QVariant>&);
-    virtual ~KeyboardDaemon();
+    ~KeyboardDaemon() override;
 };
 
 #endif /* KEYBOARD_DAEMON_H_ */
