@@ -122,7 +122,7 @@ void LibinputConfig::load()
 
     if (!m_backend->getConfig()) {
         m_errorMessage->setMessageType(KMessageWidget::Error);
-        m_errorMessage->setText(i18n("Error while loading values. See logs for more informations. Please restart this configuration module."));
+        m_errorMessage->setText(i18n("Error while loading values. See logs for more information. Please restart this configuration module."));
         m_errorMessage->animatedShow();
     } else {
         if (!m_backend->deviceCount()) {
@@ -138,7 +138,7 @@ void LibinputConfig::save()
 {
     if (!m_backend->applyConfig()) {
         m_errorMessage->setMessageType(KMessageWidget::Error);
-        m_errorMessage->setText(i18n("Not able to save all changes. See logs for more informations. Please restart this configuration module and try again."));
+        m_errorMessage->setText(i18n("Not able to save all changes. See logs for more information. Please restart this configuration module and try again."));
         m_errorMessage->animatedShow();
     } else {
         hideErrorMessage();
