@@ -19,8 +19,9 @@
 #include "touchpadconfigplugin.h"
 #include "touchpadconfigcontainer.h"
 
-TouchpadConfigPlugin::TouchpadConfigPlugin(QWidget *parent)
+TouchpadConfigPlugin::TouchpadConfigPlugin(QWidget *parent, TouchpadBackend *backend)
     : QWidget(parent),
-      m_parent(dynamic_cast<TouchpadConfigContainer*>(parent))
+      m_parent(dynamic_cast<TouchpadConfigContainer*>(parent)),
+      m_backend(backend)
 {
 }
